aboutsummaryrefslogtreecommitdiffstats
path: root/jnlib/argparse.c
diff options
context:
space:
mode:
authorWerner Koch <[email protected]>2006-06-20 17:21:37 +0000
committerWerner Koch <[email protected]>2006-06-20 17:21:37 +0000
commitf98537733ac96fd7e786286944fd3c2696229c4f (patch)
tree15bbe73728de694165d8ed9a4128ab9fbcb8eb66 /jnlib/argparse.c
parentAdd MAC t P12 files. (diff)
downloadgnupg-f98537733ac96fd7e786286944fd3c2696229c4f.tar.gz
gnupg-f98537733ac96fd7e786286944fd3c2696229c4f.zip
Updated FSF's address.
Diffstat (limited to '')
-rw-r--r--jnlib/argparse.c30
1 files changed, 16 insertions, 14 deletions
diff --git a/jnlib/argparse.c b/jnlib/argparse.c
index 980d1186c..15a7c546e 100644
--- a/jnlib/argparse.c
+++ b/jnlib/argparse.c
@@ -1,21 +1,22 @@
/* [argparse.c wk 17.06.97] Argument Parser for option handling
* Copyright (C) 1998, 1999, 2000, 2001 Free Software Foundation, Inc.
*
- * This file is part of GnuPG.
+ * This file is part of GnuPG.
*
- * GnuPG is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * GnuPG is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
*
- * GnuPG is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * GnuPG is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
*/
#include <config.h>
@@ -904,7 +905,7 @@ strusage( int level )
switch( level ) {
case 11: p = "foo"; break;
case 13: p = "0.0"; break;
- case 14: p = "Copyright (C) 2005 Free Software Foundation, Inc."; break;
+ case 14: p = "Copyright (C) 2006 Free Software Foundation, Inc."; break;
case 15: p =
"This program comes with ABSOLUTELY NO WARRANTY.\n"
"This is free software, and you are welcome to redistribute it\n"
@@ -920,7 +921,8 @@ strusage( int level )
"GNU General Public License for more details.\n\n"
"You should have received a copy of the GNU General Public License\n"
"along with this program; if not, write to the Free Software\n"
-"Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n";
+"Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,\n"
+"USA.\n";
break;
case 40: /* short and long usage */
case 41: p = ""; break;
@@ -1,21 +1,22 @@
*
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+ * USA.
*/
#include <config.h>